==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/General/converter/translations/converter_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="169"/>
        <source>Track: %1</source>
        <translation>Трек: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="171"/>
        <source>Preset: %1</source>
        <translation>Предустановка: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="266"/>
        <source>Encoding...</source>
        <translation>Кодирование...</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Converter Settings</source>
        <translation>Настройки преобразователя</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="29"/>
        <source>Select tracks to convert:</source>
        <translation>Выберите треки для преобразования:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="43"/>
        <source>Output directory:</source>
        <translation>Выходная директория:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="53"/>
        <source>Output file name:</source>
        <translation>Имя выходного файла:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Preset:</source>
        <translation>Предустановка:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="73"/>
        <source>Overwrite existing files</source>
        <translation>Перезаписывать существующие файлы</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="90"/>
        <source>Choose a directory</source>
        <translation>Выберите директорию</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="110"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="111"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="112"/>
        <source>Album Artist</source>
        <translation>Исполнитель альбома</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="113"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="114"/>
        <source>Track Number</source>
        <translation>Номер трека</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="115"/>
        <source>Two-digit Track Number</source>
        <translation>2-х разрядный номер трека</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="120"/>
        <source>Disc Number</source>
        <translation>Номер диска</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="121"/>
        <source>File Name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="122"/>
        <source>File Path</source>
        <translation>Путь к файлу</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="116"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="117"/>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="118"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="119"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="123"/>
        <source>Year</source>
        <translation>Год</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="124"/>
        <source>Condition</source>
        <translation>Условие</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="130"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="131"/>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="132"/>
        <source>Create a Copy</source>
        <translation>Сделать копию</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="133"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="28"/>
        <source>Converter Plugin</source>
        <translation>Модуль преобр. форматов</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="49"/>
        <source>About Converter Plugin</source>
        <translation>О преобразователе форматов</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>Qmmp Converter Plugin</source>
        <translation>Модуль преобразования аудио-форматов для Qmmp</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>Этот модуль предназначен для преобразования поддерживаемых аудио-файлов в другой формат с использованием внешних консольных программ</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="35"/>
        <source>Convert</source>
        <translation>Преобразовать</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="36"/>
        <source>Meta+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="42"/>
        <source>Converting...</source>
        <translation>Преобразование...</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Редактор предустановок</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>Расширение:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>Добавлять теги</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>Преобразовать в 16 бит</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (только для чтения)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>Выходной файл</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>Входной файл</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/converter/translations/converter_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="130"/>
        <location filename="../converter.cpp" line="230"/>
        <source>Cancelled</source>
        <translation>Отменено</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="145"/>
        <location filename="../converter.cpp" line="212"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="177"/>
        <source>Converting</source>
        <translation>Преобразование</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="241"/>
        <source>Encoding</source>
        <translation>Кодирование</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="279"/>
        <source>Finished</source>
        <translation>Завершено</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Audio Converter</source>
        <translation>Преобразователь аудио-форматов</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="44"/>
        <source>Progress</source>
        <translation>Выполнено</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="49"/>
        <source>State</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Output directory:</source>
        <translation>Выходная директория:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="80"/>
        <source>Output file name:</source>
        <translation>Имя выходного файла:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="97"/>
        <source>Preset:</source>
        <translation>Предустановка:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="114"/>
        <source>Overwrite existing files</source>
        <translation>Перезаписывать существующие файлы</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="124"/>
        <source>Convert</source>
        <translation>Преобразовать</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="131"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="107"/>
        <source>Choose a directory</source>
        <translation>Выберите директорию</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="190"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="191"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="192"/>
        <source>Album Artist</source>
        <translation>Исполнитель альбома</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="39"/>
        <location filename="../converterdialog.cpp" line="193"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="194"/>
        <source>Track Number</source>
        <translation>Номер трека</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="195"/>
        <source>Two-digit Track Number</source>
        <translation>2-х разрядный номер трека</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="200"/>
        <source>Disc Number</source>
        <translation>Номер диска</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="201"/>
        <source>File Name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="202"/>
        <source>File Path</source>
        <translation>Путь к файлу</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="196"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="128"/>
        <location filename="../converterdialog.cpp" line="367"/>
        <location filename="../converterdialog.cpp" line="373"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="133"/>
        <source>Waiting</source>
        <translation>Ожидание</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="197"/>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="198"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="199"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="203"/>
        <source>Year</source>
        <translation>Год</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="204"/>
        <source>Condition</source>
        <translation>Условие</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="210"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="211"/>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="212"/>
        <source>Create a Copy</source>
        <translation>Сделать копию</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="213"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="367"/>
        <source>Unable to execute &quot;%1&quot;. Program not found.</source>
        <translation>Невозможно запустить &quot;%1&quot;. Программа не найдена.</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="373"/>
        <source>Process &quot;%1&quot; finished with error.</source>
        <translation>Процесс &quot;%1&quot; завершился с ошибкой.</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="30"/>
        <source>Converter Plugin</source>
        <translation>Модуль преобр. форматов</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>About Converter Plugin</source>
        <translation>О преобразователе форматов</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="52"/>
        <source>Qmmp Converter Plugin</source>
        <translation>Модуль преобразования аудио-форматов для Qmmp</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>Этот модуль предназначен для преобразования поддерживаемых аудио-файлов в другой формат с использованием внешних консольных программ</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="33"/>
        <source>Convert</source>
        <translation>Преобразовать</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="34"/>
        <source>Meta+C</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Редактор предустановок</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>Расширение:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>Добавлять теги</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>Преобразовать в 16 бит</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (только для чтения)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>Выходной файл</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>Входной файл</translation>
    </message>
</context>
</TS>
